# Obtaining API Keys

In this section we indicate where the API keys for the different LLMs can be obtained.

## OpenAI

To obtain an OpenAI API key, visit [this page](https://platform.openai.com/api-keys) and follow the instructions.

## Gemini

To obtain a Gemini API key, visit [this page](https://ai.google.dev/gemini-api/docs/api-key) and follow the link to Google AI Studio to generate your key.

## Anthropic

To obtain an Anthropic API key, visit [this page](https://console.anthropic.com/settings/keys) and follow the instructions.

## Perplexity

To obtain a Perplexity API key, visit [this page](https://docs.perplexity.ai/getting-started/quickstart) and follow the instructions.

## FutureHouse

Denario can use [FutureHouse](https://www.futurehouse.org/)'s Owl agent for precedent search (i.e., checking if an idea has been previously explored). To obtain an API key, visit [this page](https://platform.futurehouse.org/) and follow the instructions.
